{% extends "base.html" %}

{% block content %}
    {% block pagebody %}
        {% with block.super as body_content %}
        {% block pagetext %}
            {{ body_content }}
        {% endblock %}
        {% endwith %}
        {% block profilenav %}
            {% include "profiles/_profile_menu.html" %}
        {% endblock %}
    {% endblock %}
{% endblock %}
